YaruPanedView class
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- YaruPanedView
Constructors
-
YaruPanedView({Key? key, required Widget pane, required Widget page, required YaruPanedViewLayoutDelegate layoutDelegate, ValueChanged<
double> ? onPaneSizeChange, bool includeSeparator = true}) -
const
-
YaruPanedView.builder({Key? key, required YaruPaneBuilder paneBuilder, required WidgetBuilder pageBuilder, required YaruPanedViewLayoutDelegate layoutDelegate, ValueChanged<
double> ? onPaneSizeChange, bool includeSeparator = true}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- includeSeparator → bool
-
If true, a Divider will be added between the pane and the page.
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- layoutDelegate → YaruPanedViewLayoutDelegate
-
Controls the size, side and resizing capacity of the pane.
final
-
onPaneSizeChange
→ ValueChanged<
double> ? -
Called each time the pane size change.
final
- page → Widget?
-
Page widget child.
final
- pageBuilder → WidgetBuilder?
-
Page widget child builder.
final
- pane → Widget?
-
Pane widget child.
final
- paneBuilder → YaruPaneBuilder?
-
Pane widget child builder, taking the available space as a parameter.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< YaruPanedView> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited